import ancestor from "common-ancestor-path";
import { isPage, isEndpoint } from "../core/util.js";
import * as eslexer from "es-module-lexer";
const BOOLEAN_EXPORTS = /* @__PURE__ */ new Set(["prerender"]);
function astroScannerPlugin({ settings }) {
  function normalizeFilename(filename) {
    if (filename.startsWith("/@fs")) {
      filename = filename.slice("/@fs".length);
    } else if (filename.startsWith("/") && !ancestor(filename, settings.config.root.pathname)) {
      filename = new URL("." + filename, settings.config.root).pathname;
    }
    return filename;
  }
  return {
    name: "astro:scanner",
    enforce: "post",
    async transform(code, id, options) {
      if (!(options == null ? void 0 : options.ssr))
        return;
      const filename = normalizeFilename(id);
      let fileURL;
      try {
        fileURL = new URL(`file://${filename}`);
      } catch (e) {
        return;
      }
      const fileIsPage = isPage(fileURL, settings);
      const fileIsEndpoint = isEndpoint(fileURL, settings);
      if (!(fileIsPage || fileIsEndpoint))
        return;
      await eslexer.init;
      const [_, exports] = eslexer.parse(code, id);
      let pageOptions = {};
      for (const e of exports) {
        if (BOOLEAN_EXPORTS.has(e.n)) {
          pageOptions[e.n] = true;
          let expr = code.slice(e.le).trim().replace(/\=/, "").trim().split(/[;\n]/)[0];
          if (expr !== "true") {
          }
        }
      }
      const { meta = {} } = this.getModuleInfo(id) ?? {};
      return {
        code,
        meta: {
          ...meta,
          astro: {
            ...meta.astro ?? { hydratedComponents: [], clientOnlyComponents: [], scripts: [] },
            pageOptions
          }
        }
      };
    }
  };
}
export {
  astroScannerPlugin as default
};
